<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 Awarez Ltd.                                       |
| For contact details, see: http://www.awarez.net/                          |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: Common.php 2403 2005-04-07 12:43:50Z andrew $
*/

/**
 * @package    MaxMaintenance
 * @subpackage Priority
 * @author     Andrew Hill <andrew@awarez.net>
 */

require_once 'Date.php';

/**
 * An abstract class used to specify the interface for classes that forecast the
 * expected number of impressions in each operation interval, for each zone.
 *
 * @abstract
 */
class Maintenance_Priority_AdServer_ZoneImpressionForecast_Common
{
    var $conf;
    var $now;
    var $report;
    var $updateAll;
    var $updateRange;
    
    /**
     * A common constructor method that can be used by each subclass of the interface.
     *
     * The constructor method determines when the last time the Maintenance Priority
     * process last updated the forecast of expected impressions, and compares this
     * with the last time the Maintenance Statistics process last updated the
     * statistics. If necessary, the constructor sets the required operation intervals
     * that require that their zone impression forecasts be updated.
     *
     * @param Date $now Optional Date representing the current date/time.
     *                  Used for testing the constructor method.
     *
     * @TODO Needs to be written.
     */
    function Maintenance_Priority_AdServer_ZoneImpressionForecast_Common($now = null)
    {
        $this->conf = $GLOBALS['_MAX']['CONF'];
        if (!is_null($now)) {
            $this->now = $now;
        } else {
            $this->now = new Date();
        }
        // set $this->updateAll = false
        // set $this->updateRange = null (or null range, anyway)
        // $stat = DAL call to get most recent Stats update from log_maintenance_statistics
        // $prio = DAL call to get most recent Priority update from log_maintenance_priority
        // _setUpdateRange($stat, $prio);
        
    }
 
    /**
     * A method for updating the forecast of the expected number of impressions
     * for each operation interval, for each zone.
     */
    function forecastZoneImpressions() {}
    
    /**
     * An internal method for setting the range of operation intervals that need to be updated.
     */
    function _setUpdateRange($stat, $prio)
    {
        // if $stat is null, no stats, so exit
        // if $prio is null, never run before, update all ($this->updateAll = true)
        // if $prio->operation_interval different to current operation_interval, the
        //   operation interval has changed since the last priority update, so 
        //   update all
        // if $stat->date not in the same operation interval as $this->now, then
        //   stats has not been updated this operation interval yet, so cannot 
        //   update priority to now - check to see if $stat->date is after
        //   $prio->date, and if not, there are no operation intervals to update,
        //   so exit. Howver, if $stat->date is after $prio->date, there may be
        //   some operation intervals which can have the ZIF updated, so set
        //   the date we will use as "now" to $stat->date
        // else, set the date will use as "now" to $this->now
        // if "now" is more than one week after $prio->date, a week has passed
        //   since the ZIFs were updated, so update all
        // else, calculate all operation intervals between $prio->date and
        //   "now", excluding the operation interval that $prio->date is in, 
        //   but including the operation interval that "now" is in, and
        //   store in $this->updateRange: see Maintenance::getOperationIntervalRange()
    }
    
}

?>
