<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.2                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 Awarez Ltd.                                       |
| For contact details, see: http://www.awarez.net/                          |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: adview.plugin.php 2280 2005-03-30 14:05:56Z radek $
*/

/**
 * @package    Plugins
 * @subpackage InvocationTags
 * @author     Radek Maciaszek <radek@awarez.net>
 *
 */

require_once MAX_PATH . '/plugins/invocationTags/InvocationTags.php';
require_once MAX_PATH . '/lib/max/Plugins/PluginTranslation.php';

/**
 *
 * Invocation tag plugin.
 *
 */
class Plugins_InvocationTags_adview_adview extends Plugins_InvocationTags 
{
    
    /**
     * Return name of plugin
     *
     * @return string
     */
    function getName()
    {
        return Max_PluginTranslation::translate('Remote Invocation', $this->module, $this->package);
    }
    
    /**
     * Return preference code
     *
     * @return string
     */
    function getPreferenceCode()
    {
        return 'allow_invocation_plain';
    }
    
    /**
     * Check if plugin is allowed
     *
     * @return boolean  True - allowed, false - not allowed
     */
    function isAllowed($extra)
    {
        $isAllowed = parent::isAllowed($extra);
        if(is_array($extra) && $extra['delivery'] == phpAds_ZoneText) {
            return false;
        } else {
            return $isAllowed;
        }
    }
    
    /**
     * Return list of options
     *
     * @return array    Group of options
     */
    function getOptionsList()
    {
        $options = array (
            'spacer'      => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
            'what'       => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
            'campaignid' => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
            'target'     => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
            'source'     => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
        );
        
        return $options;
    }    

    /**
     * Return invocation code for this plugin (codetype)
     *
     * @return string
     */
    function generateInvocationCode()
    {
        parent::prepareCommonInvocationData();
        
        $conf = $GLOBALS['_MAX']['CONF'];
        $mi = &$this->maxInvocation;
        
        $buffer  = '<!-- Max Media Manager Remote Invocation Tag' . "\n";
        $buffer .= '  --' . "\n";
        $buffer .= '  -- Generated with Max ' . MAX_VERSION_READABLE . "\n";
        $buffer .= '  --' . "\n";
        $buffer .= '  -- This tag has been generated for use on a non-SSL page. If this tag' . "\n";
        $buffer .= '  -- is to be placed on an SSL page, change the' . "\n";
        $buffer .= '  --   \'http://'.$conf['webpath']['delivery'].'/...\'' . "\n";
        $buffer .= '  -- to' . "\n";
        $buffer .= '  --   \'https://'.$conf['webpath']['deliverySSL'].'/...\'' . "\n";
        $buffer .= '  --' . "\n";
        $buffer .= '  -- This tag only shows image banners. There is no width or height in' . "\n";
        $buffer .= '  -- these banners, so if you want these tags to allocate space for the' . "\n";
        $buffer .= '  -- ad before it shows, you will need to add this information to the' . "\n";
        $buffer .= '  -- <img> tag.' . "\n";
        $buffer .= '  -->' . "\n\n";
        if (isset($mi->uniqueid) && $mi->uniqueid != '') {
            $mi->parameters[] = "n=".$mi->uniqueid;
        }
        $buffer .= "<a href='".constructDeliveryURL($conf['file']['click']);
        $buffer .= "?n=".$mi->uniqueid;
        $buffer .= "'";
        if (isset($mi->target) && $mi->target != '') {
            $buffer .= " target='".$mi->target."'";
        } else {
            $buffer .= " target='_blank'";
        }
        $buffer .= "><img src='".constructDeliveryURL($conf['file']['view']);
        if (sizeof($mi->parameters) > 0) {
            $buffer .= "?".implode ("&", $mi->parameters);
        }
        $buffer .= "' border='0' alt='' /></a>\n";
        
        return $buffer;
    }

}

?>